@@ -22,7 +22,10 @@
 """duplicity's gpg interface, builds upon Frank Tobin's GnuPGInterface"""
 
 import select, os, sys, thread, types, cStringIO, tempfile, re, gzip
-import GnuPGInterface, misc, log
+import misc, log
+
+import duplicity.globals as globals
+import duplicity.GnuPGInterface as GnuPGInterface
 
 try:
     from hashlib import sha1
@@ -91,6 +94,8 @@ class GPGFile:
         gnupg = GnuPGInterface.GnuPG()
         gnupg.options.meta_interactive = 0
         gnupg.options.extra_args.append('--no-secmem-warning')
+        if globals.use_agent:
+            gnupg.options.extra_args.append('--use-agent')
         if gpg_options:
             for opt in gpg_options.split():
                 gnupg.options.extra_args.append(opt)
